==> vlc-0.8.1.tar.gz: vlc-0.8.1/modules/access/cdda/access.h <==
/*****************************************************************************
 * access.h : access headers for CD digital audio input module
 *****************************************************************************
 * Copyright (C) 2004 VideoLAN
 * $Id: access.h 8606 2004-08-31 18:32:54Z rocky $
 *
 * Authors: Rocky Bernstein <rocky@panix.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111, USA.
 *****************************************************************************/

/*****************************************************************************
 * Open: open cdda device or image file and initialize structures 
 * for subsequent operations.
 *****************************************************************************/
int  E_(CDDAOpen)     ( vlc_object_t * );

/*****************************************************************************
 * CDDAClose: closes cdda and frees any resources associded with it.
 *****************************************************************************/
void E_(CDDAClose)    ( vlc_object_t * );

==> vlc-0.8.2.tar.gz: vlc-0.8.2/modules/access/cdda/access.h <==
/*****************************************************************************
 * access.h : access headers for CD digital audio input module
 *****************************************************************************
 * Copyright (C) 2004 VideoLAN
 * $Id: access.h 8606 2004-08-31 18:32:54Z rocky $
 *
 * Authors: Rocky Bernstein <rocky@panix.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111, USA.
 *****************************************************************************/

/*****************************************************************************
 * Open: open cdda device or image file and initialize structures 
 * for subsequent operations.
 *****************************************************************************/
int  CDDAOpen     ( vlc_object_t * );

/*****************************************************************************
 * CDDAClose: closes cdda and frees any resources associded with it.
 *****************************************************************************/
void CDDAClose    ( vlc_object_t * );
